# -*- coding: utf-8 -*-

"""
mesh loader
"""

# imports ####################################################################

import os
import sys

lib_path = os.path.join(os.path.dirname(__file__), "..", "lib")
sys.path.append(os.path.abspath(lib_path))

from linalg import vector as _v


# micro parsers ##############################################################

def vertex(x, y, z="0", w="1"):
	w = float(w)
	return float(x)/w, float(y)/w, float(z)/w

def color(r, g, b, a="1"):
	return float(r), float(g), float(b), float(a)

def face(color, vertex_indicies):
	f = Face()
	f.color = color
	f.vertex_indicies = [int(i)-1 for i in vertex_indicies]
	return f


# mesh #######################################################################

class Face(object):
	pass

class Mesh(object):
	"""3D mesh."""
	
	def __init__(self, mesh_name, verbose=True):
		self.verticies = []
		self.faces = []
		
		p_max = [float("-inf")] * 3
		p_min  = [float("inf")] * 3 
		
		current_color = (.5, .5, .5, 1.)
		
		mesh_file = open(mesh_name, 'r')
		for line in mesh_file:
			words = line.split()
			try:
				command, args = words[0], words[1:]
			except IndexError:
				continue
			
			# comments
			if command[0] == '#':
				if verbose:
					print line,
			
			# vertex
			elif command == "v":
				v = vertex(*args)
				p_max = map(max, p_max, v)
				p_min = map(min, p_min, v)
				self.verticies.append(v)
			
			# face
			elif command == "f":
				self.faces.append(face(current_color, args))
			
			# color
			elif command == "c":
				current_color = color(*args)
		
		mesh_file.close()
		
		self.center = _v.mul(.5, _v.add(p_min, p_max))
		self.radius = .5 * max(_v.sub(p_max, p_min))
	
	
	def display(self):
		print "center, radius:", self.center, self.radius
		print "faces:"
		for f in self.faces:
			print f.color
			for i in f.vertex_indicies:
				print self.verticies[i],
			print
