#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
mesh viewer
"""


# imports ####################################################################

import os
import sys

from math import exp

from OpenGL.GL import *
from OpenGL.GLUT import *

import mesh


# constants ##################################################################

WINDOW_SIZE = 640, 480


# viewer class ###############################################################

class Viewer:
	"""A simple glut viewer"""

	def __init__(self, mesh_name):
		# openGL initialisation
		self.init_glut()
		self.init_gl()
		
		# mesh
		self.mesh = mesh.Mesh(mesh_name)


# OpenGL #####################################################################

	def init_glut(self):
		glutCreateWindow("viewer")
		glutReshapeFunc(self.reshape)
		glutDisplayFunc(self.display)
		glutKeyboardFunc(self.keyboard)
		
	def init_gl(self):
		# clear color
		glClearColor(1, 1, 1, 1)
	
	
# glut callbacks ###############################################################
	
	def reshape(self, width, height):
		# setting viewport
		glViewport(0, 0, width, height)

		# setting projection
		pass
	
	
	def display(self):
		# clearing the back buffer
		glClear(GL_COLOR_BUFFER_BIT)

		# setting the model view
		pass

		# rendering the object in back buffer ...
		glColor(0, 0, 0)
		glBegin(GL_TRIANGLE_STRIP)
		for x in [-.5, .5]:
			for y in [-.5, .5]:
				glVertex(x, y)
		glEnd()
				
		# ... and on screen
		glutSwapBuffers()


	def keyboard(self, key, x, y):
		# quit
		if key in ['q', chr(27)]:
			print 'quitting'
			sys.exit(0)
		
		glutPostRedisplay()
		
		
# main #########################################################################

def main(argv = None):
	if argv is None:
		argv = sys.argv

	glutInit(argv)
	glutInitDisplayMode(GLUT_RGBA|GLUT_DOUBLE)
	glutInitWindowSize(*WINDOW_SIZE)
	
	mesh_name = os.path.join(os.path.dirname(__file__), "teapot.obj")

	argc = len(argv)
	assert argc <= 2
	if argc == 2:
		mesh_name = os.path.join(os.getcwd(), argv[1])

	viewer = Viewer(mesh_name)
	
	glutMainLoop()


if __name__ == '__main__':
	sys.exit(main())
